/*
 * anonpgpid.d - anonymous memory paging info by process on CPU.
 *               Written using DTrace (Solaris 10 3/05).
 *
 * This scripts may help identify which processes are affected by a system
 * with low memory, which is paging to the physical swap device. A report
 * of the process on the CPU when paging occured is printed.
 *
 * $Id: anonpgpid.d 8 2007-08-06 05:55:26Z brendan $
 *
 * FIELDS:
 *		PID		Process ID
 *		CMD		Process name
 *		D		Direction, Read or Write
 *		BYTES		Total bytes during sample
 *
 * NOTES:
 *
 * This program is currently an approximation - often the process when writing
 * pages to swap will be "pageout" the pageout scanner, or "rcapd" the
 * resource capping daemon.
 *
 * THANKS: James Dickens
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * TODO:
 *
 * Track processes accurately. This is a little difficult - anonpgout
 * occurs asynchronously to the process, and events related to this don't
 * point back to the process.
 *
 * Author: Brendan Gregg  [Sydney, Australia]
 *
 * 25-Jul-2005	Brendan Gregg	Created this.
 * 18-Feb-2006	   "      "	Last update.
 * 23-Oct-2008	Tom Erickson (adapted to Chime)
 */

/*
 * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

#include <sys/vnode.h>

fbt::pageio_setup:entry
/((args[2]->v_flag & (VISSWAP | VSWAPLIKE)) != 0) && (args[3] & B_READ)/
{
	@read[pid, execname] = sum(arg1);
}

fbt::pageio_setup:entry
/((args[2]->v_flag & (VISSWAP | VSWAPLIKE)) != 0) && (args[3] & B_WRITE)/
{
	@write[pid, execname] = sum(arg1);
}
